from distutils.core import setup

setup(
    name='CO2Signal',
    description='A package to access the co2signal API',
    url='https://github.com/danielsjf/CO2Signal',
    version='0.3',
    packages=['CO2Signal', ],
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description=open('README.md').read(),
)